"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QEventPoint(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qeventpoint.html

    **Detailed Description**
    """

    class State(enum.Flag):
        Unknown: QEventPoint = ...
        Stationary: QEventPoint = ...
        Pressed: QEventPoint = ...
        Updated: QEventPoint = ...
        Released: QEventPoint = ...

    @typing.overload
    def __init__(
        self,
        pointId: int,
        state: "QEventPoint.State",
        scenePosition: QtCore.QPointF,
        globalPosition: QtCore.QPointF,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#QEventPoint-1

        **QEventPoint::QEventPoint(int pointId , QEventPoint::State state ,
        const QPointF & scenePosition , const QPointF & globalPosition )**

        Constructs an event point with the given **pointId** , **state** ,
        **scenePosition** and **globalPosition**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QEventPoint") -> None:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#QEventPoint-2

        **QEventPoint::QEventPoint(const QEventPoint & other )**

        Constructs an event point by making a shallow copy of **other**.
        """
        ...

    def setAccepted(self, accepted: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#accepted-prop

        **accepted : bool**

        This property holds the accepted state of the event point.

        In widget-based applications, this property is not used, as it's only
        meaningful for a widget to accept or reject a complete **QInputEvent** .

        In Qt Quick however, it's normal for an Item or Event Handler to accept
        only the individual points in a **QTouchEvent**  that are actually
        participating in a gesture, while other points can be delivered to other
        items or handlers. For the sake of consistency, that applies to any
        **QPointerEvent** ; and delivery is done only when all points in a
        **QPointerEvent**  have been accepted.

        **Access functions:**

        bool **isAccepted** () const
        void **setAccepted** (bool **accepted** =
        true)

        **See also** **QEvent::accepted** .
        """
        ...

    def isAccepted(self) -> bool:
        ...

    def ellipseDiameters(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#ellipseDiameters-prop

        **[read-only] ellipseDiameters : const QSizeF**

        This property holds the width and height of the bounding ellipse of the
        touch point.

        The return value is in logical pixels. Most touchscreens do not detect
        the shape of the contact point, and no mice or tablet devices can detect
        it, so a null size is the most common value. On some touchscreens the
        diameters may be nonzero and always equal (the ellipse is approximated
        as a circle).

        **Access functions:**

        QSizeF **ellipseDiameters** () const
        """
        ...

    def rotation(self) -> float:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#rotation-prop

        **[read-only] rotation : const qreal**

        This property holds the angular orientation of this point.

        The return value is in degrees, where zero (the default) indicates the
        finger, token or stylus is pointing upwards, a negative angle means it's
        rotated to the left, and a positive angle means it's rotated to the
        right. Most touchscreens do not detect rotation, so zero is the most
        common value.

        **Access functions:**

        qreal **rotation** () const
        """
        ...

    def pressure(self) -> float:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#pressure-prop

        **[read-only] pressure : const qreal**

        This property holds the pressure of this point.

        The return value is in the range `0.0` to `1.0`.

        **Access functions:**

        qreal **pressure** () const
        """
        ...

    def timeHeld(self) -> float:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#timeHeld-prop

        **[read-only] timeHeld : const qreal**

        This property holds the duration, in milliseconds, since this point was
        pressed and not released.

        **Access functions:**

        qreal **timeHeld** () const

        **See also** **pressTimestamp**  and **timestamp** .
        """
        ...

    def pressTimestamp(self) -> int:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#pressTimestamp-prop

        **[read-only] pressTimestamp : const ulong**

        This property holds the most recent time at which this point was
        pressed.

        **Access functions:**

        ulong **pressTimestamp** () const

        **See also** **timestamp** .
        """
        ...

    def lastTimestamp(self) -> int:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#lastTimestamp-prop

        **[read-only] lastTimestamp : const ulong**

        This property holds the time from the previous **QPointerEvent**  that
        contained this point.

        **Access functions:**

        ulong **lastTimestamp** () const

        **See also** **globalLastPosition** .
        """
        ...

    def timestamp(self) -> int:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#timestamp-prop

        **[read-only] timestamp : const ulong**

        This property holds the most recent time at which this point was
        included in a **QPointerEvent** .

        **Access functions:**

        ulong **timestamp** () const

        **See also** **QPointerEvent::timestamp** ().
        """
        ...

    def uniqueId(self) -> "QPointingDeviceUniqueId":
        """
        https://doc.qt.io/qt-6/qeventpoint.html#uniqueId-prop

        **[read-only] uniqueId : const QPointingDeviceUniqueId**

        This property holds the unique ID of this point or token, if any.

        It is often invalid (see **isValid** ()), because touchscreens cannot
        uniquely identify fingers.

        When it comes from a **QTabletEvent** , it identifies the serial number
        of the stylus in use.

        It may identify a specific token (fiducial object) when the TUIO driver
        is in use with a touchscreen that supports them.

        **Access functions:**

        QPointingDeviceUniqueId **uniqueId** () const
        """
        ...

    def id(self) -> int:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#id-prop

        **[read-only] id : const int**

        This property holds the ID number of this event point.

        **Note:** Do not assume that ID numbers start at zero or that they are
        sequential. Such an assumption is often false due to the way the
        underlying drivers work.

        **Access functions:**

        int **id** () const
        """
        ...

    def device(self) -> "QPointingDevice":
        """
        https://doc.qt.io/qt-6/qeventpoint.html#device-prop

        **[read-only] device : QPointingDevice* const**

        This property holds the pointing device from which this event point
        originates.

        **Access functions:**

        const QPointingDevice * ****device** ** () const
        """
        ...

    def state(self) -> "QEventPoint.State":
        """
        https://doc.qt.io/qt-6/qeventpoint.html#state-prop

        **[read-only] state : const State**

        This property holds the current state of the event point.

        **Access functions:**

        QEventPoint::State **state** () const
        """
        ...

    def velocity(self) -> "QVector2D":
        """
        https://doc.qt.io/qt-6/qeventpoint.html#velocity-prop

        **[read-only] velocity : const QVector2D**

        This property holds a velocity vector, in units of pixels per second, in
        the coordinate. system of the screen or desktop.

        **Note:** If the device's capabilities include
        **QInputDevice::Velocity** , it means velocity comes from the operating
        system (perhaps the touch hardware or driver provides it). But usually
        the `Velocity` capability is not set, indicating that the velocity is
        calculated by Qt, using a simple Kalman filter to provide a smoothed
        average velocity rather than an instantaneous value. Effectively it
        tells how fast and in what direction the user has been dragging this
        point over the last few events, with the most recent event having the
        strongest influence.

        **Access functions:**

        QVector2D **velocity** () const

        **See also** **QInputDevice::capabilities** () and
        **QInputEvent::device** ().

        **Member Function Documentation**
        """
        ...

    def normalizedPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#normalizedPosition

        **QPointF QEventPoint::normalizedPosition() const**

        Returns the normalized position of this point.

        The coordinates are calculated by transforming **globalPosition** ()
        into the space of **QInputDevice::availableVirtualGeometry** (), i.e.
        `(0, 0)` is the top-left corner and `(1, 1)` is the bottom-right corner.

        **See also** **globalPosition** .
        """
        ...

    def globalLastPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#globalLastPosition-prop

        **[read-only] globalLastPosition : const QPointF**

        This property holds the global position of this point from the previous
        press or move event.

        The global position is relative to the screen or virtual desktop.

        **Access functions:**

        QPointF **globalLastPosition** () const

        **See also** **globalPosition** , **lastPosition** , and
        **sceneLastPosition** .
        """
        ...

    def globalGrabPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#globalGrabPosition-prop

        **[read-only] globalGrabPosition : const QPointF**

        This property holds the global position at which this point was grabbed.

        The global position is relative to the screen or virtual desktop.

        **Access functions:**

        QPointF **globalGrabPosition** () const

        **See also** **globalPosition** , **grabPosition** , and
        **sceneGrabPosition** .
        """
        ...

    def globalPressPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#globalPressPosition-prop

        **[read-only] globalPressPosition : const QPointF**

        This property holds the global position at which this point was pressed.

        The global position is relative to the screen or virtual desktop.

        **Access functions:**

        QPointF **globalPressPosition** () const

        **See also** **globalPosition** , **pressPosition** , and
        **scenePressPosition** .
        """
        ...

    def globalPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#globalPosition-prop

        **[read-only] globalPosition : const QPointF**

        This property holds the global position of this point.

        The global position is relative to the screen or virtual desktop.

        **Access functions:**

        QPointF **globalPosition** () const

        **See also** **globalPressPosition** , **position** , and
        **scenePosition** .
        """
        ...

    def sceneLastPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#sceneLastPosition-prop

        **[read-only] sceneLastPosition : const QPointF**

        This property holds the scene position of this point from the previous
        press or move event.

        The scene position is the position relative to **QQuickWindow**  if
        handled in **QQuickItem::event** (), in **QGraphicsScene**  coordinates
        if handled by an override of QGraphicsItem::touchEvent(), or the window
        position in widget applications.

        **Access functions:**

        QPointF **sceneLastPosition** () const

        **See also** **scenePosition**  and **scenePressPosition** .
        """
        ...

    def sceneGrabPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#sceneGrabPosition-prop

        **[read-only] sceneGrabPosition : const QPointF**

        This property holds the scene position at which this point was grabbed.

        The scene position is the position relative to **QQuickWindow**  if
        handled in **QQuickItem::event** (), in **QGraphicsScene**  coordinates
        if handled by an override of QGraphicsItem::touchEvent(), or the window
        position in widget applications.

        **Access functions:**

        QPointF **sceneGrabPosition** () const

        **See also** **scenePosition** , **grabPosition** , and
        **globalGrabPosition** .
        """
        ...

    def scenePressPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#scenePressPosition-prop

        **[read-only] scenePressPosition : const QPointF**

        This property holds the scene position at which this point was pressed.

        The scene position is the position relative to **QQuickWindow**  if
        handled in **QQuickItem::event** (), in **QGraphicsScene**  coordinates
        if handled by an override of QGraphicsItem::touchEvent(), or the window
        position in widget applications.

        **Access functions:**

        QPointF **scenePressPosition** () const

        **See also** **scenePosition** , **pressPosition** , and
        **globalPressPosition** .
        """
        ...

    def scenePosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#scenePosition-prop

        **[read-only] scenePosition : const QPointF**

        This property holds the scene position of this point.

        The scene position is the position relative to **QQuickWindow**  if
        handled in **QQuickItem::event** (), in **QGraphicsScene**  coordinates
        if handled by an override of QGraphicsItem::touchEvent(), or the window
        position in widget applications.

        **Access functions:**

        QPointF **scenePosition** () const

        **See also** **scenePressPosition** , **position** , and
        **globalPosition** .
        """
        ...

    def lastPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#lastPosition-prop

        **[read-only] lastPosition : const QPointF**

        This property holds the position of this point from the previous press
        or move event.

        The position is relative to the widget or item that received the event.

        **Access functions:**

        QPointF **lastPosition** () const

        **See also** **position**  and **pressPosition** .
        """
        ...

    def grabPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#grabPosition-prop

        **[read-only] grabPosition : const QPointF**

        This property holds the position at which this point was grabbed.

        The position is relative to the widget or item that received the event.

        **Access functions:**

        QPointF **grabPosition** () const

        **See also** **position** .
        """
        ...

    def pressPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#pressPosition-prop

        **[read-only] pressPosition : const QPointF**

        This property holds the position at which this point was pressed.

        The position is relative to the widget or item that received the event.

        **Access functions:**

        QPointF **pressPosition** () const

        **See also** **position** .
        """
        ...

    def position(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qeventpoint.html#position-prop

        **[read-only] position : const QPointF**

        This property holds the position of this point.

        The position is relative to the widget or item that received the event.

        **Access functions:**

        QPointF **position** () const
        """
        ...

    def swap(self, other: "QEventPoint") -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QProgressDialog(QDialog):
    """
    https://doc.qt.io/qt-6/qprogressdialog.html

    **Detailed Description**

    A progress dialog is used to give the user an indication of how long an
    operation is going to take, and to demonstrate that the application has not
    frozen. It can also give the user an opportunity to abort the operation.

    A common problem with progress dialogs is that it is difficult to know when
    to use them; operations take different amounts of time on different
    hardware. QProgressDialog offers a solution to this problem: it estimates
    the time the operation will take (based on time for steps), and only shows
    itself if that estimate is beyond **minimumDuration** () (4 seconds by
    default).

    Use **setMinimum** () and **setMaximum** () or the constructor to set the
    number of "steps" in the operation and call **setValue** () as the operation
    progresses. The number of steps can be chosen arbitrarily. It can be the
    number of files copied, the number of bytes received, the number of
    iterations through the main loop of your algorithm, or some other suitable
    unit. Progress starts at the value set by **setMinimum** (), and the
    progress dialog shows that the operation has finished when you call
    **setValue** () with the value set by **setMaximum** () as its argument.

    The dialog automatically resets and hides itself at the end of the
    operation. Use **setAutoReset** () and **setAutoClose** () to change this
    behavior. Note that if you set a new maximum (using **setMaximum** () or
    **setRange** ()) that equals your current **value** (), the dialog will not
    close regardless.

    There are two ways of using QProgressDialog: modal and modeless.

    Compared to a modeless QProgressDialog, a modal QProgressDialog is simpler
    to use for the programmer. Do the operation in a loop, call **setValue** ()
    at intervals, and check for cancellation with **wasCanceled** (). For
    example:

    **QProgressDialog**  progress("Copying files...", "Abort Copy", 0, numFiles,
    this);
            progress.setWindowModality(Qt::WindowModal);

            for
    (int i = 0; i < numFiles; i++) {
                progress.setValue(i);
    if (progress.wasCanceled())
                    break;
                //... copy
    one file
            }
            progress.setValue(numFiles);

    A modeless progress dialog is suitable for operations that take place in the
    background, where the user is able to interact with the application. Such
    operations are typically based on **QTimer**  (or **QObject::timerEvent**
    ()) or **QSocketNotifier** ; or performed in a separate thread. A
    **QProgressBar**  in the status bar of your main window is often an
    alternative to a modeless progress dialog.

    You need to have an event loop to be running, connect the **canceled** ()
    signal to a slot that stops the operation, and call **setValue** () at
    intervals. For example:

    // Operation constructor
        Operation::Operation(**QObject**  *parent)
    : **QObject** (parent), steps(0)
        {
            pd = new **QProgressDialog**
    ("Operation in progress.", "Cancel", 0, 100);
            connect(pd,
    &**QProgressDialog** ::canceled, this, &Operation::cancel);
            t = new
    **QTimer** (this);
            connect(t, &**QTimer** ::timeout, this,
    &Operation::perform);
            t->start(0);
        }

        void
    Operation::perform()
        {
            pd->setValue(steps);
            //...
    perform one percent of the operation
            steps++;
            if (steps >
    pd->maximum())
                t->stop();
        }

        void
    Operation::cancel()
        {
            t->stop();
            //... cleanup
        }

    In both modes the progress dialog may be customized by replacing the child
    widgets with custom widgets by using **setLabel** (), **setBar** (), and
    **setCancelButton** (). The functions **setLabelText** () and
    **setCancelButtonText** () set the texts shown.

    ![A progress dialog shown in the Fusion widget style.](images/fusion-
    progressdialog.png)

    **See also** **QDialog** , **QProgressBar** , **GUI Design Handbook:
    Progress Indicator** , **Find Files Example** , and **Pixelator Example** .
    """

    @typing.overload
    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#QProgressDialog

        **QProgressDialog::QProgressDialog(QWidget * parent = nullptr,
        Qt::WindowFlags f = Qt::WindowFlags())**

        Constructs a progress dialog.

        Default settings:

        * The label text is empty.
          * The cancel button text is (translated)
        "Cancel".
          * minimum is 0;
          * maximum is 100

        The **parent** argument is dialog's parent widget. The widget flags,
        **f** , are passed to the **QDialog::QDialog** () constructor.

        **See also** **setLabelText** (), **setCancelButtonText** (),
        **setCancelButton** (), **setMinimum** (), and **setMaximum** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        labelText: str,
        cancelButtonText: str,
        minimum: int,
        maximum: int,
        parent: typing.Optional[QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#QProgressDialog-1

        **QProgressDialog::QProgressDialog(const QString & labelText , const
        QString & cancelButtonText , int minimum , int maximum , QWidget *
        parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags())**

        Constructs a progress dialog.

        The **labelText** is the text used to remind the user what is
        progressing.

        The **cancelButtonText** is the text to display on the cancel button. If
        QString() is passed then no cancel button is shown.

        The **minimum** and **maximum** is the number of steps in the operation
        for which this progress dialog shows progress. For example, if the
        operation is to examine 50 files, this value minimum value would be 0,
        and the maximum would be 50. Before examining the first file, call
        **setValue** (0). As each file is processed call **setValue** (1),
        **setValue** (2), etc., finally calling **setValue** (50) after
        examining the last file.

        The **parent** argument is the dialog's parent widget. The parent,
        **parent** , and widget flags, **f** , are passed to the
        **QDialog::QDialog** () constructor.

        **See also** **setLabelText** (), **setLabel** (),
        **setCancelButtonText** (), **setCancelButton** (), **setMinimum** (),
        and **setMaximum** ().
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#open

        **void QProgressDialog::open(QObject * receiver , const char * member
        )**

        Opens the dialog and connects its **canceled** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#open

        **void QProgressDialog::open(QObject * receiver , const char * member
        )**

        Opens the dialog and connects its **canceled** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def forceShow(self) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#forceShow

        **[protected slot] void QProgressDialog::forceShow()**

        Shows the dialog if it is still hidden after the algorithm has been
        started and **minimumDuration**  milliseconds have passed.

        **See also** **setMinimumDuration** ().
        """
        ...

    def showEvent(self, e: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#showEvent

        **[override virtual protected] void
        QProgressDialog::showEvent(QShowEvent * e )**

        Reimplements: **QDialog::showEvent** (QShowEvent *event).
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#changeEvent

        **[override virtual protected] void QProgressDialog::changeEvent(QEvent
        * ev )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def closeEvent(self, a0: QtGui.QCloseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#closeEvent

        **[override virtual protected] void
        QProgressDialog::closeEvent(QCloseEvent * e )**

        Reimplements: **QDialog::closeEvent** (QCloseEvent *e).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#resizeEvent

        **[override virtual protected] void
        QProgressDialog::resizeEvent(QResizeEvent * event )**

        Reimplements: **QDialog::resizeEvent** (QResizeEvent *).
        """
        ...

    def setMinimumDuration(self, ms: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#minimumDuration-prop

        **minimumDuration : int**

        This property holds the time that must pass before the dialog appears

        If the expected duration of the task is less than the minimumDuration,
        the dialog will not appear at all. This prevents the dialog popping up
        for tasks that are quickly over. For tasks that are expected to exceed
        the minimumDuration, the dialog will pop up after the minimumDuration
        time or as soon as any progress is set.

        If set to 0, the dialog is always shown as soon as any progress is set.
        The default is 4000 milliseconds.

        **Access functions:**

        int **minimumDuration** () const
        void **setMinimumDuration** (int
        **ms** )
        """
        ...

    def setCancelButtonText(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#setCancelButtonText

        **[slot] void QProgressDialog::setCancelButtonText(const QString &
        cancelButtonText )**

        Sets the cancel button's text to **cancelButtonText**. If the text is
        set to QString() then it will cause the cancel button to be hidden and
        deleted.

        **See also** **setCancelButton** ().
        """
        ...

    def setLabelText(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#labelText-prop

        **labelText : QString**

        This property holds the label's text

        The default text is an empty string.

        **Access functions:**

        QString **labelText** () const
        void **setLabelText** (const QString &
        **text** )
        """
        ...

    def setValue(self, progress: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#value-prop

        **value : int**

        This property holds the current amount of progress made.

        For the progress dialog to work as expected, you should initially set
        this property to **QProgressDialog::minimum** () and finally set it to
        **QProgressDialog::maximum** (); you can call setValue() any number of
        times in-between.

        **Warning:** If the progress dialog is modal (see
        **QProgressDialog::QProgressDialog** ()), setValue() calls
        **QCoreApplication::processEvents** (), so take care that this does not
        cause undesirable re-entrancy in your code. For example, don't use a
        **QProgressDialog**  inside a **paintEvent** ()!

        **Access functions:**

        int **value** () const
        void **setValue** (int **progress** )

        **See also** **minimum**  and **maximum** .
        """
        ...

    def setMinimum(self, minimum: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#minimum-prop

        **minimum : int**

        This property holds the lowest value represented by the progress bar

        The default is 0.

        **Access functions:**

        int **minimum** () const
        void **setMinimum** (int **minimum** )

        **See also** **maximum**  and **setRange** ().
        """
        ...

    def setMaximum(self, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#maximum-prop

        **maximum : int**

        This property holds the highest value represented by the progress bar

        The default is 100.

        **Access functions:**

        int **maximum** () const
        void **setMaximum** (int **maximum** )

        **See also** **minimum**  and **setRange** ().
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#reset

        **[slot] void QProgressDialog::reset()**

        Resets the progress dialog. The progress dialog becomes hidden if
        **autoClose** () is true.

        **See also** **setAutoClose** () and **setAutoReset** ().
        """
        ...

    def cancel(self) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#cancel

        **[slot] void QProgressDialog::cancel()**

        Resets the progress dialog. **wasCanceled** () becomes true until the
        progress dialog is reset. The progress dialog becomes hidden.
        """
        ...

    def autoClose(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#autoClose-prop

        **autoClose : bool**

        This property holds whether the dialog gets hidden by **reset** ()

        The default is true.

        **Access functions:**

        bool **autoClose** () const
        void **setAutoClose** (bool **close** )

        **See also** **setAutoReset** ().
        """
        ...

    def setAutoClose(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#autoClose-prop

        **autoClose : bool**

        This property holds whether the dialog gets hidden by **reset** ()

        The default is true.

        **Access functions:**

        bool **autoClose** () const
        void **setAutoClose** (bool **close** )

        **See also** **setAutoReset** ().
        """
        ...

    def autoReset(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#autoReset-prop

        **autoReset : bool**

        This property holds whether the progress dialog calls **reset** () as
        soon as **value** () equals **maximum** ()

        The default is true.

        **Access functions:**

        bool **autoReset** () const
        void **setAutoReset** (bool **reset** )

        **See also** **setAutoClose** ().
        """
        ...

    def setAutoReset(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#autoReset-prop

        **autoReset : bool**

        This property holds whether the progress dialog calls **reset** () as
        soon as **value** () equals **maximum** ()

        The default is true.

        **Access functions:**

        bool **autoReset** () const
        void **setAutoReset** (bool **reset** )

        **See also** **setAutoClose** ().
        """
        ...

    def minimumDuration(self) -> int:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#minimumDuration-prop

        **minimumDuration : int**

        This property holds the time that must pass before the dialog appears

        If the expected duration of the task is less than the minimumDuration,
        the dialog will not appear at all. This prevents the dialog popping up
        for tasks that are quickly over. For tasks that are expected to exceed
        the minimumDuration, the dialog will pop up after the minimumDuration
        time or as soon as any progress is set.

        If set to 0, the dialog is always shown as soon as any progress is set.
        The default is 4000 milliseconds.

        **Access functions:**

        int **minimumDuration** () const
        void **setMinimumDuration** (int
        **ms** )
        """
        ...

    def labelText(self) -> str:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#labelText-prop

        **labelText : QString**

        This property holds the label's text

        The default text is an empty string.

        **Access functions:**

        QString **labelText** () const
        void **setLabelText** (const QString &
        **text** )
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#sizeHint

        **[override virtual] QSize QProgressDialog::sizeHint() const**

        Reimplements: **QDialog::sizeHint() const** .

        Returns a size that fits the contents of the progress dialog. The
        progress dialog resizes itself as required, so you should not need to
        call this yourself.
        """
        ...

    def value(self) -> int:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#value-prop

        **value : int**

        This property holds the current amount of progress made.

        For the progress dialog to work as expected, you should initially set
        this property to **QProgressDialog::minimum** () and finally set it to
        **QProgressDialog::maximum** (); you can call setValue() any number of
        times in-between.

        **Warning:** If the progress dialog is modal (see
        **QProgressDialog::QProgressDialog** ()), setValue() calls
        **QCoreApplication::processEvents** (), so take care that this does not
        cause undesirable re-entrancy in your code. For example, don't use a
        **QProgressDialog**  inside a **paintEvent** ()!

        **Access functions:**

        int **value** () const
        void **setValue** (int **progress** )

        **See also** **minimum**  and **maximum** .
        """
        ...

    def setRange(self, minimum: int, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#setRange

        **[slot] void QProgressDialog::setRange(int minimum , int maximum )**

        Sets the progress dialog's minimum and maximum values to **minimum** and
        **maximum** , respectively.

        If **maximum** is smaller than **minimum** , **minimum** becomes the
        only legal value.

        If the current value falls outside the new range, the progress dialog is
        reset with **reset** ().

        **See also** **minimum**  and **maximum** .
        """
        ...

    def maximum(self) -> int:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#maximum-prop

        **maximum : int**

        This property holds the highest value represented by the progress bar

        The default is 100.

        **Access functions:**

        int **maximum** () const
        void **setMaximum** (int **maximum** )

        **See also** **minimum**  and **setRange** ().
        """
        ...

    def minimum(self) -> int:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#minimum-prop

        **minimum : int**

        This property holds the lowest value represented by the progress bar

        The default is 0.

        **Access functions:**

        int **minimum** () const
        void **setMinimum** (int **minimum** )

        **See also** **maximum**  and **setRange** ().
        """
        ...

    def wasCanceled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#wasCanceled-prop

        **[read-only] wasCanceled : const bool**

        This property holds whether the dialog was canceled

        **Access functions:**

        bool **wasCanceled** () const

        **Member Function Documentation**
        """
        ...

    def setBar(self, bar: QProgressBar) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#setBar

        **void QProgressDialog::setBar(QProgressBar * bar )**

        Sets the progress bar widget to **bar**. The progress dialog resizes to
        fit. The progress dialog takes ownership of the progress **bar** which
        will be deleted when necessary, so do not use a progress bar allocated
        on the stack.
        """
        ...

    def setCancelButton(self, button: QPushButton) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#setCancelButton

        **void QProgressDialog::setCancelButton(QPushButton * cancelButton )**

        Sets the cancel button to the push button, **cancelButton**. The
        progress dialog takes ownership of this button which will be deleted
        when necessary, so do not pass the address of an object that is on the
        stack, i.e. use new() to create the button. If `nullptr` is passed, no
        cancel button will be shown.

        **See also** **setCancelButtonText** ().
        """
        ...

    def setLabel(self, label: QLabel) -> None:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#setLabel

        **void QProgressDialog::setLabel(QLabel * label )**

        Sets the label to **label**. The progress dialog resizes to fit. The
        label becomes owned by the progress dialog and will be deleted when
        necessary, so do not pass the address of an object on the stack.

        **See also** **setLabelText** ().
        """
        ...

    @property
    def canceled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprogressdialog.html#canceled

        **[signal] void QProgressDialog::canceled()**

        This signal is emitted when the cancel button is clicked. It is
        connected to the **cancel** () slot by default.

        **See also** **wasCanceled** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtQml import *

PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]


def qmlRegisterUncreatableType(
    a0: type,
    uri: str,
    major: int,
    minor: int,
    reason: str,
    qmlName: typing.Optional[str] = ...,
) -> int:
    ...


def qmlRegisterAnonymousType(a0: type, uri: str, major: int) -> int:
    ...


def qmlRegisterSingletonInstance(
    uri: str, major: int, minor: int, typeName: str, cppObject: QtCore.QObject
) -> int:
    ...


def qmlRegisterRevision(
    a0: type, uri: str, major: int, minor: int, attachedProperties: type = ...
) -> int:
    ...


def qmlAttachedPropertiesObject(
    a0: type, object: QtCore.QObject, create: bool = ...
) -> QtCore.QObject:
    ...


def qjsEngine(a0: QtCore.QObject) -> QJSEngine:
    ...


def qmlEngine(a0: QtCore.QObject) -> QQmlEngine:
    ...


def qmlContext(a0: QtCore.QObject) -> QQmlContext:
    ...


def qmlTypeId(uri: str, versionMajor: int, versionMinor: int, qmlName: str) -> int:
    ...


@typing.overload
def qmlRegisterType(
    url: QtCore.QUrl, uri: str, versionMajor: int, versionMinor: int, qmlName: str
) -> int:
    ...


@typing.overload
def qmlRegisterType(
    a0: type,
    uri: str,
    major: int,
    minor: int,
    name: typing.Optional[str] = ...,
    attachedProperties: type = ...,
) -> int:
    ...


@typing.overload
def qmlRegisterSingletonType(
    url: QtCore.QUrl, uri: str, versionMajor: int, versionMinor: int, qmlName: str
) -> int:
    ...


@typing.overload
def qmlRegisterSingletonType(
    a0: type,
    uri: str,
    major: int,
    minor: int,
    factory: typing.Callable[[QQmlEngine, QJSEngine], typing.Any],
    name: typing.Optional[str] = ...,
) -> int:
    ...


def qmlRegisterModule(uri: str, versionMajor: int, versionMinor: int) -> None:
    ...


def qmlProtectModule(uri: str, majVersion: int) -> bool:
    ...


def qmlRegisterUncreatableMetaObject(
    staticMetaObject: QtCore.QMetaObject,
    uri: str,
    versionMajor: int,
    versionMinor: int,
    qmlName: str,
    reason: str,
) -> int:
    ...


def qmlRegisterTypeNotAvailable(
    uri: str, versionMajor: int, versionMinor: int, qmlName: str, message: str
) -> int:
    ...


def qmlClearTypeRegistrations() -> None:
    ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtGui import *
import enum


class QTextCursor(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextcursor.html

    **Detailed Description**

    Text cursors are objects that are used to access and modify the contents and
    underlying structure of text documents via a programming interface that
    mimics the behavior of a cursor in a text editor. QTextCursor contains
    information about both the cursor's position within a **QTextDocument**  and
    any selection that it has made.

    QTextCursor is modeled on the way a text cursor behaves in a text editor,
    providing a programmatic means of performing standard actions through the
    user interface. A document can be thought of as a single string of
    characters. The cursor's current **position** () then is always either
    **between** two consecutive characters in the string, or else **before** the
    very first character or **after** the very last character in the string.
    Documents can also contain tables, lists, images, and other objects in
    addition to text but, from the developer's point of view, the document can
    be treated as one long string. Some portions of that string can be
    considered to lie within particular blocks (e.g. paragraphs), or within a
    table's cell, or a list's item, or other structural elements. When we refer
    to "current character" we mean the character immediately **before** the
    cursor **position** () in the document. Similarly, the "current block" is
    the block that contains the cursor **position** ().

    A QTextCursor also has an **anchor** () position. The text that is between
    the **anchor** () and the **position** () is the selection. If **anchor** ()
    == **position** () there is no selection.

    The cursor position can be changed programmatically using **setPosition** ()
    and **movePosition** (); the latter can also be used to select text. For
    selections see **selectionStart** (), **selectionEnd** (), **hasSelection**
    (), **clearSelection** (), and **removeSelectedText** ().

    If the **position** () is at the start of a block, **atBlockStart** ()
    returns `true`; and if it is at the end of a block, **atBlockEnd** ()
    returns true. The format of the current character is returned by
    **charFormat** (), and the format of the current block is returned by
    **blockFormat** ().

    Formatting can be applied to the current text document using the
    **setCharFormat** (), **mergeCharFormat** (), **setBlockFormat** () and
    **mergeBlockFormat** () functions. The 'set' functions will replace the
    cursor's current character or block format, while the 'merge' functions add
    the given format properties to the cursor's current format. If the cursor
    has a selection, the given format is applied to the current selection. Note
    that when only a part of a block is selected, the block format is applied to
    the entire block. The text at the current character position can be turned
    into a list using **createList** ().

    Deletions can be achieved using **deleteChar** (), **deletePreviousChar**
    (), and **removeSelectedText** ().

    Text strings can be inserted into the document with the **insertText** ()
    function, blocks (representing new paragraphs) can be inserted with
    **insertBlock** ().

    Existing fragments of text can be inserted with **insertFragment** () but,
    if you want to insert pieces of text in various formats, it is usually still
    easier to use **insertText** () and supply a character format.

    Various types of higher-level structure can also be inserted into the
    document with the cursor:

    * Lists are ordered sequences of block elements that are decorated with
    bullet points or symbols. These are inserted in a specified format with
    **insertList** ().
      * Tables are inserted with the **insertTable** ()
    function, and can be given an optional format. These contain an array of
    cells that can be traversed using the cursor.
      * Inline images are inserted
    with **insertImage** (). The image to be used can be specified in an image
    format, or by name.
      * Frames are inserted by calling **insertFrame** ()
    with a specified format.

    Actions can be grouped (i.e. treated as a single action for undo/redo) using
    **beginEditBlock** () and **endEditBlock** ().

    Cursor movements are limited to valid cursor positions. In Latin writing
    this is between any two consecutive characters in the text, before the first
    character, or after the last character. In some other writing systems cursor
    movements are limited to "clusters" (e.g. a syllable in Devanagari, or a
    base letter plus diacritics). Functions such as **movePosition** () and
    **deleteChar** () limit cursor movement to these valid positions.

    **See also** **Rich Text Processing** .
    """

    class SelectionType(enum.Enum):
        WordUnderCursor: QTextCursor = ...
        LineUnderCursor: QTextCursor = ...
        BlockUnderCursor: QTextCursor = ...
        Document: QTextCursor = ...

    class MoveOperation(enum.Enum):
        NoMove: QTextCursor = ...
        Start: QTextCursor = ...
        Up: QTextCursor = ...
        StartOfLine: QTextCursor = ...
        StartOfBlock: QTextCursor = ...
        StartOfWord: QTextCursor = ...
        PreviousBlock: QTextCursor = ...
        PreviousCharacter: QTextCursor = ...
        PreviousWord: QTextCursor = ...
        Left: QTextCursor = ...
        WordLeft: QTextCursor = ...
        End: QTextCursor = ...
        Down: QTextCursor = ...
        EndOfLine: QTextCursor = ...
        EndOfWord: QTextCursor = ...
        EndOfBlock: QTextCursor = ...
        NextBlock: QTextCursor = ...
        NextCharacter: QTextCursor = ...
        NextWord: QTextCursor = ...
        Right: QTextCursor = ...
        WordRight: QTextCursor = ...
        NextCell: QTextCursor = ...
        PreviousCell: QTextCursor = ...
        NextRow: QTextCursor = ...
        PreviousRow: QTextCursor = ...

    class MoveMode(enum.Enum):
        MoveAnchor: QTextCursor = ...
        KeepAnchor: QTextCursor = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#QTextCursor

        **QTextCursor::QTextCursor()**

        Constructs a null cursor.
        """
        ...

    @typing.overload
    def __init__(self, document: "QTextDocument") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#QTextCursor-1

        **QTextCursor::QTextCursor(QTextDocument * document )**

        Constructs a cursor pointing to the beginning of the **document**.
        """
        ...

    @typing.overload
    def __init__(self, frame: "QTextFrame") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#QTextCursor-2

        **QTextCursor::QTextCursor(QTextFrame * frame )**

        Constructs a cursor pointing to the beginning of the **frame**.
        """
        ...

    @typing.overload
    def __init__(self, block: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#QTextCursor-3

        **QTextCursor::QTextCursor(const QTextBlock & block )**

        Constructs a cursor pointing to the beginning of the **block**.
        """
        ...

    @typing.overload
    def __init__(self, cursor: "QTextCursor") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#QTextCursor-4

        **QTextCursor::QTextCursor(const QTextCursor & cursor )**

        Constructs a new cursor that is a copy of **cursor**.
        """
        ...

    def swap(self, other: "QTextCursor") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#swap

        **[since 5.0] void QTextCursor::swap(QTextCursor & other )**

        Swaps this text cursor instance with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def keepPositionOnInsert(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#keepPositionOnInsert

        **bool QTextCursor::keepPositionOnInsert() const**

        Returns whether the cursor should keep its current position when text
        gets inserted at the position of the cursor.

        The default is false;

        **See also** **setKeepPositionOnInsert** ().
        """
        ...

    def setKeepPositionOnInsert(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#setKeepPositionOnInsert

        **void QTextCursor::setKeepPositionOnInsert(bool b )**

        Defines whether the cursor should keep its current position when text
        gets inserted at the current position of the cursor.

        If **b** is true, the cursor keeps its current position when text gets
        inserted at the positing of the cursor. If **b** is false, the cursor
        moves along with the inserted text.

        The default is false.

        Note that a cursor always moves when text is inserted before the current
        position of the cursor, and it always keeps its position when text is
        inserted after the current position of the cursor.

        **See also** **keepPositionOnInsert** ().
        """
        ...

    def verticalMovementX(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#verticalMovementX

        **int QTextCursor::verticalMovementX() const**

        Returns the visual x position for vertical cursor movements.

        A value of -1 indicates no predefined x position. It will then be set
        automatically the next time the cursor moves up or down.

        **See also** **setVerticalMovementX** ().
        """
        ...

    def setVerticalMovementX(self, x: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#setVerticalMovementX

        **void QTextCursor::setVerticalMovementX(int x )**

        Sets the visual x position for vertical cursor movements to **x**.

        The vertical movement x position is cleared automatically when the
        cursor moves horizontally, and kept unchanged when the cursor moves
        vertically. The mechanism allows the cursor to move up and down on a
        visually straight line with proportional fonts, and to gently "jump"
        over short lines.

        A value of -1 indicates no predefined x position. It will then be set
        automatically the next time the cursor moves up or down.

        **See also** **verticalMovementX** ().
        """
        ...

    def positionInBlock(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#positionInBlock

        **int QTextCursor::positionInBlock() const**

        Returns the relative position of the cursor within the block. The cursor
        is positioned between characters.

        This is equivalent to `position() - block().position()`.

        **Note:** The "characters" in this case refer to the string of **QChar**
        objects, i.e. 16-bit Unicode characters, and the position is considered
        an index into this string. This does not necessarily correspond to
        individual graphemes in the writing system, as a single grapheme may be
        represented by multiple Unicode characters, such as in the case of
        surrogate pairs, linguistic ligatures or diacritics.

        **See also** **position** ().
        """
        ...

    def document(self) -> "QTextDocument":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#document

        **QTextDocument *QTextCursor::document() const**

        Returns the document this cursor is associated with.
        """
        ...

    def setVisualNavigation(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#setVisualNavigation

        **void QTextCursor::setVisualNavigation(bool b )**

        Sets visual navigation to **b**.

        Visual navigation means skipping over hidden text paragraphs. The
        default is false.

        **See also** **visualNavigation** () and **movePosition** ().
        """
        ...

    def visualNavigation(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#visualNavigation

        **bool QTextCursor::visualNavigation() const**

        Returns `true` if the cursor does visual navigation; otherwise returns
        `false`.

        Visual navigation means skipping over hidden text paragraphs. The
        default is false.

        **See also** **setVisualNavigation** () and **movePosition** ().
        """
        ...

    def isCopyOf(self, other: "QTextCursor") -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#isCopyOf

        **bool QTextCursor::isCopyOf(const QTextCursor & other ) const**

        Returns `true` if this cursor and **other** are copies of each other,
        i.e. one of them was created as a copy of the other and neither has
        moved since. This is much stricter than equality.

        **See also** **operator=** () and **operator==** ().
        """
        ...

    def columnNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#columnNumber

        **int QTextCursor::columnNumber() const**

        Returns the position of the cursor within its containing line.

        Note that this is the column number relative to a wrapped line, not
        relative to the block (i.e. the paragraph).

        You probably want to call **positionInBlock** () instead.

        **See also** **positionInBlock** ().
        """
        ...

    def blockNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#blockNumber

        **int QTextCursor::blockNumber() const**

        Returns the number of the block the cursor is in, or 0 if the cursor is
        invalid.

        Note that this function only makes sense in documents without complex
        objects such as tables or frames.
        """
        ...

    def endEditBlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#endEditBlock

        **void QTextCursor::endEditBlock()**

        Indicates the end of a block of editing operations on the document that
        should appear as a single operation from an undo/redo point of view.

        **See also** **beginEditBlock** ().
        """
        ...

    def joinPreviousEditBlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#joinPreviousEditBlock

        **void QTextCursor::joinPreviousEditBlock()**

        Like **beginEditBlock** () indicates the start of a block of editing
        operations that should appear as a single operation for undo/redo.
        However unlike **beginEditBlock** () it does not start a new block but
        reverses the previous call to **endEditBlock** () and therefore makes
        following operations part of the previous edit block created.

        For example:

        **QTextCursor**  cursor(textDocument);
            cursor.beginEditBlock();
        cursor.insertText("Hello");
            cursor.insertText("World");
        cursor.endEditBlock();

            // ...
        cursor.joinPreviousEditBlock();
            cursor.insertText("Hey");
        cursor.endEditBlock();

            textDocument->undo();

        The call to undo() will cause all three insertions to be undone.

        **See also** **beginEditBlock** () and **endEditBlock** ().
        """
        ...

    def beginEditBlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#beginEditBlock

        **void QTextCursor::beginEditBlock()**

        Indicates the start of a block of editing operations on the document
        that should appear as a single operation from an undo/redo point of
        view.

        For example:

        **QTextCursor**  cursor(textDocument);
            cursor.beginEditBlock();
        cursor.insertText("Hello");
            cursor.insertText("World");
        cursor.endEditBlock();

            textDocument->undo();

        The call to undo() will cause both insertions to be undone, causing both
        "World" and "Hello" to be removed.

        It is possible to nest calls to beginEditBlock and **endEditBlock** .
        The top-most pair will determine the scope of the undo/redo operation.

        **See also** **endEditBlock** ().
        """
        ...

    @typing.overload
    def insertImage(self, format: "QTextImageFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertImage

        **void QTextCursor::insertImage(const QTextImageFormat & format )**

        Inserts the image defined by **format** at the current **position** ().
        """
        ...

    @typing.overload
    def insertImage(
        self, format: "QTextImageFormat", alignment: "QTextFrameFormat.Position"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertImage-1

        **void QTextCursor::insertImage(const QTextImageFormat & format ,
        QTextFrameFormat::Position alignment )**

        This is an overloaded function.

        Inserts the image defined by the given **format** at the cursor's
        current position with the specified **alignment**.

        **See also** **position** ().
        """
        ...

    @typing.overload
    def insertImage(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertImage-2

        **void QTextCursor::insertImage(const QString & name )**

        This is an overloaded function.

        Convenience method for inserting the image with the given **name** at
        the current **position** ().

        **QImage**  img;
            textDocument->addResource(**QTextDocument**
        ::ImageResource, **QUrl** ("myimage"), img);
        cursor.insertImage("myimage");
        """
        ...

    @typing.overload
    def insertImage(self, image: QImage, name: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertImage-3

        **void QTextCursor::insertImage(const QImage & image , const QString &
        name = QString())**

        This is an overloaded function.

        Convenience function for inserting the given **image** with an optional
        **name** at the current **position** ().
        """
        ...

    def insertHtml(self, html: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertHtml

        **void QTextCursor::insertHtml(const QString & html )**

        Inserts the text **html** at the current **position** (). The text is
        interpreted as HTML.

        **Note:** When using this function with a style sheet, the style sheet
        will only apply to the current block in the document. In order to apply
        a style sheet throughout a document, use
        **QTextDocument::setDefaultStyleSheet** () instead.
        """
        ...

    def insertFragment(self, fragment: "QTextDocumentFragment") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertFragment

        **void QTextCursor::insertFragment(const QTextDocumentFragment &
        fragment )**

        Inserts the text **fragment** at the current **position** ().
        """
        ...

    def currentFrame(self) -> "QTextFrame":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#currentFrame

        **QTextFrame *QTextCursor::currentFrame() const**

        Returns a pointer to the current frame. Returns `nullptr` if the cursor
        is invalid.

        **See also** **insertFrame** ().
        """
        ...

    def insertFrame(self, format: "QTextFrameFormat") -> "QTextFrame":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertFrame

        **QTextFrame *QTextCursor::insertFrame(const QTextFrameFormat & format
        )**

        Inserts a frame with the given **format** at the current cursor
        **position** (), moves the cursor **position** () inside the frame, and
        returns the frame.

        If the cursor holds a selection, the whole selection is moved inside the
        frame.

        **See also** **hasSelection** ().
        """
        ...

    def currentTable(self) -> "QTextTable":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#currentTable

        **QTextTable *QTextCursor::currentTable() const**

        Returns a pointer to the current table if the cursor **position** () is
        inside a block that is part of a table; otherwise returns `nullptr`.

        **See also** **insertTable** ().
        """
        ...

    @typing.overload
    def insertTable(
        self, rows: int, cols: int, format: "QTextTableFormat"
    ) -> "QTextTable":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertTable

        **QTextTable *QTextCursor::insertTable(int rows , int columns , const
        QTextTableFormat & format )**

        Creates a new table with the given number of **rows** and **columns** in
        the specified **format** , inserts it at the current cursor **position**
        () in the document, and returns the table object. The cursor is moved to
        the beginning of the first cell.

        There must be at least one row and one column in the table.

        **See also** **currentTable** ().
        """
        ...

    @typing.overload
    def insertTable(self, rows: int, cols: int) -> "QTextTable":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertTable-1

        **QTextTable *QTextCursor::insertTable(int rows , int columns )**

        This is an overloaded function.

        Creates a new table with the given number of **rows** and **columns** ,
        inserts it at the current cursor **position** () in the document, and
        returns the table object. The cursor is moved to the beginning of the
        first cell.

        There must be at least one row and one column in the table.

        **See also** **currentTable** ().
        """
        ...

    def currentList(self) -> "QTextList":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#currentList

        **QTextList *QTextCursor::currentList() const**

        Returns the current list if the cursor **position** () is inside a block
        that is part of a list; otherwise returns `nullptr`.

        **See also** **insertList** () and **createList** ().
        """
        ...

    @typing.overload
    def createList(self, format: "QTextListFormat") -> "QTextList":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#createList

        **QTextList *QTextCursor::createList(const QTextListFormat & format )**

        Creates and returns a new list with the given **format** , and makes the
        current paragraph the cursor is in the first list item.

        **See also** **insertList** () and **currentList** ().
        """
        ...

    @typing.overload
    def createList(self, style: "QTextListFormat.Style") -> "QTextList":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#createList-1

        **QTextList *QTextCursor::createList(QTextListFormat::Style style )**

        This is an overloaded function.

        Creates and returns a new list with the given **style** , making the
        cursor's current paragraph the first list item.

        The style to be used is defined by the **QTextListFormat::Style**  enum.

        **See also** **insertList** () and **currentList** ().
        """
        ...

    @typing.overload
    def insertList(self, format: "QTextListFormat") -> "QTextList":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertList

        **QTextList *QTextCursor::insertList(const QTextListFormat & format )**

        Inserts a new block at the current position and makes it the first list
        item of a newly created list with the given **format**. Returns the
        created list.

        **See also** **currentList** (), **createList** (), and **insertBlock**
        ().
        """
        ...

    @typing.overload
    def insertList(self, style: "QTextListFormat.Style") -> "QTextList":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertList-1

        **QTextList *QTextCursor::insertList(QTextListFormat::Style style )**

        This is an overloaded function.

        Inserts a new block at the current position and makes it the first list
        item of a newly created list with the given **style**. Returns the
        created list.

        **See also** **currentList** (), **createList** (), and **insertBlock**
        ().
        """
        ...

    @typing.overload
    def insertBlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertBlock

        **void QTextCursor::insertBlock()**

        Inserts a new empty block at the cursor **position** () with the current
        **blockFormat** () and **charFormat** ().

        **See also** **setBlockFormat** ().
        """
        ...

    @typing.overload
    def insertBlock(self, format: "QTextBlockFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertBlock-1

        **void QTextCursor::insertBlock(const QTextBlockFormat & format )**

        This is an overloaded function.

        Inserts a new empty block at the cursor **position** () with block
        format **format** and the current **charFormat** () as block char
        format.

        **See also** **setBlockFormat** ().
        """
        ...

    @typing.overload
    def insertBlock(
        self, format: "QTextBlockFormat", charFormat: "QTextCharFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertBlock-2

        **void QTextCursor::insertBlock(const QTextBlockFormat & format , const
        QTextCharFormat & charFormat )**

        This is an overloaded function.

        Inserts a new empty block at the cursor **position** () with block
        format **format** and **charFormat** as block char format.

        **See also** **setBlockFormat** ().
        """
        ...

    def atEnd(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#atEnd

        **bool QTextCursor::atEnd() const**

        Returns `true` if the cursor is at the end of the document; otherwise
        returns `false`.

        **See also** **atStart** () and **atBlockEnd** ().
        """
        ...

    def atStart(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#atStart

        **bool QTextCursor::atStart() const**

        Returns `true` if the cursor is at the start of the document; otherwise
        returns `false`.

        **See also** **atBlockStart** () and **atEnd** ().
        """
        ...

    def atBlockEnd(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#atBlockEnd

        **bool QTextCursor::atBlockEnd() const**

        Returns `true` if the cursor is at the end of a block; otherwise returns
        `false`.

        **See also** **atBlockStart** () and **atEnd** ().
        """
        ...

    def atBlockStart(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#atBlockStart

        **bool QTextCursor::atBlockStart() const**

        Returns `true` if the cursor is at the start of a block; otherwise
        returns `false`.

        **See also** **atBlockEnd** () and **atStart** ().
        """
        ...

    def mergeBlockCharFormat(self, modifier: "QTextCharFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#mergeBlockCharFormat

        **void QTextCursor::mergeBlockCharFormat(const QTextCharFormat &
        modifier )**

        Modifies the block char format of the current block (or all blocks that
        are contained in the selection) with the block format specified by
        **modifier**.

        **See also** **setBlockCharFormat** ().
        """
        ...

    def setBlockCharFormat(self, format: "QTextCharFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#setBlockCharFormat

        **void QTextCursor::setBlockCharFormat(const QTextCharFormat & format
        )**

        Sets the block char format of the current block (or all blocks that are
        contained in the selection) to **format**.

        **See also** **blockCharFormat** ().
        """
        ...

    def blockCharFormat(self) -> "QTextCharFormat":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#blockCharFormat

        **QTextCharFormat QTextCursor::blockCharFormat() const**

        Returns the block character format of the block the cursor is in.

        The block char format is the format used when inserting text at the
        beginning of an empty block.

        **See also** **setBlockCharFormat** ().
        """
        ...

    def mergeBlockFormat(self, modifier: "QTextBlockFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#mergeBlockFormat

        **void QTextCursor::mergeBlockFormat(const QTextBlockFormat & modifier
        )**

        Modifies the block format of the current block (or all blocks that are
        contained in the selection) with the block format specified by
        **modifier**.

        **See also** **setBlockFormat** () and **blockFormat** ().
        """
        ...

    def setBlockFormat(self, format: "QTextBlockFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#setBlockFormat

        **void QTextCursor::setBlockFormat(const QTextBlockFormat & format )**

        Sets the block format of the current block (or all blocks that are
        contained in the selection) to **format**.

        **See also** **blockFormat** () and **mergeBlockFormat** ().
        """
        ...

    def blockFormat(self) -> "QTextBlockFormat":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#blockFormat

        **QTextBlockFormat QTextCursor::blockFormat() const**

        Returns the block format of the block the cursor is in.

        **See also** **setBlockFormat** () and **charFormat** ().
        """
        ...

    def mergeCharFormat(self, modifier: "QTextCharFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#mergeCharFormat

        **void QTextCursor::mergeCharFormat(const QTextCharFormat & modifier )**

        Merges the cursor's current character format with the properties
        described by format **modifier**. If the cursor has a selection, this
        function applies all the properties set in **modifier** to all the
        character formats that are part of the selection.

        **See also** **hasSelection** () and **setCharFormat** ().
        """
        ...

    def setCharFormat(self, format: "QTextCharFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#setCharFormat

        **void QTextCursor::setCharFormat(const QTextCharFormat & format )**

        Sets the cursor's current character format to the given **format**. If
        the cursor has a selection, the given **format** is applied to the
        current selection.

        **See also** **charFormat** (), **hasSelection** (), and
        **mergeCharFormat** ().
        """
        ...

    def charFormat(self) -> "QTextCharFormat":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#charFormat

        **QTextCharFormat QTextCursor::charFormat() const**

        Returns the format of the character immediately before the cursor
        **position** (). If the cursor is positioned at the beginning of a text
        block that is not empty then the format of the character immediately
        after the cursor is returned.

        **See also** **setCharFormat** (), **insertText** (), and
        **blockFormat** ().
        """
        ...

    def block(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#block

        **QTextBlock QTextCursor::block() const**

        Returns the block that contains the cursor.
        """
        ...

    def selectedTableCells(self) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#selectedTableCells

        **void QTextCursor::selectedTableCells(int * firstRow , int * numRows ,
        int * firstColumn , int * numColumns ) const**

        If the selection spans over table cells, **firstRow** is populated with
        the number of the first row in the selection, **firstColumn** with the
        number of the first column in the selection, and **numRows** and
        **numColumns** with the number of rows and columns in the selection. If
        the selection does not span any table cells the results are harmless but
        undefined.
        """
        ...

    def selection(self) -> "QTextDocumentFragment":
        """
        https://doc.qt.io/qt-6/qtextcursor.html#selection

        **QTextDocumentFragment QTextCursor::selection() const**

        Returns the current selection (which may be empty) with all its
        formatting information. If you just want the selected text (i.e. plain
        text) use **selectedText** () instead.

        **Note:** Unlike **QTextDocumentFragment::toPlainText** (),
        **selectedText** () may include special unicode characters such as
        **QChar::ParagraphSeparator** .

        **See also** **QTextDocumentFragment::toPlainText** ().
        """
        ...

    def selectedText(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#selectedText

        **QString QTextCursor::selectedText() const**

        Returns the current selection's text (which may be empty). This only
        returns the text, with no rich text formatting information. If you want
        a document fragment (i.e. formatted rich text) use **selection** ()
        instead.

        **Note:** If the selection obtained from an editor spans a line break,
        the text will contain a Unicode U+2029 paragraph separator character
        instead of a newline `\\n` character. Use **QString::replace** () to
        replace these characters with newlines.
        """
        ...

    def selectionEnd(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#selectionEnd

        **int QTextCursor::selectionEnd() const**

        Returns the end of the selection or **position** () if the cursor
        doesn't have a selection.

        **See also** **selectionStart** (), **position** (), and **anchor** ().
        """
        ...

    def selectionStart(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#selectionStart

        **int QTextCursor::selectionStart() const**

        Returns the start of the selection or **position** () if the cursor
        doesn't have a selection.

        **See also** **selectionEnd** (), **position** (), and **anchor** ().
        """
        ...

    def clearSelection(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#clearSelection

        **void QTextCursor::clearSelection()**

        Clears the current selection by setting the anchor to the cursor
        position.

        Note that it does **not** delete the text of the selection.

        **See also** **removeSelectedText** () and **hasSelection** ().
        """
        ...

    def removeSelectedText(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#removeSelectedText

        **void QTextCursor::removeSelectedText()**

        If there is a selection, its content is deleted; otherwise does nothing.

        **See also** **hasSelection** ().
        """
        ...

    def hasComplexSelection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#hasComplexSelection

        **bool QTextCursor::hasComplexSelection() const**

        Returns `true` if the cursor contains a selection that is not simply a
        range from **selectionStart** () to **selectionEnd** (); otherwise
        returns `false`.

        Complex selections are ones that span at least two cells in a table;
        their extent is specified by **selectedTableCells** ().
        """
        ...

    def hasSelection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#hasSelection

        **bool QTextCursor::hasSelection() const**

        Returns `true` if the cursor contains a selection; otherwise returns
        `false`.
        """
        ...

    def select(self, selection: "QTextCursor.SelectionType") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#select

        **void QTextCursor::select(QTextCursor::SelectionType selection )**

        Selects text in the document according to the given **selection**.
        """
        ...

    def deletePreviousChar(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#deletePreviousChar

        **void QTextCursor::deletePreviousChar()**

        If there is no selected text, deletes the character **before** the
        current cursor position; otherwise deletes the selected text.

        **See also** **deleteChar** (), **hasSelection** (), and
        **clearSelection** ().
        """
        ...

    def deleteChar(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#deleteChar

        **void QTextCursor::deleteChar()**

        If there is no selected text, deletes the character **at** the current
        cursor position; otherwise deletes the selected text.

        **See also** **deletePreviousChar** (), **hasSelection** (), and
        **clearSelection** ().
        """
        ...

    def movePosition(
        self,
        op: "QTextCursor.MoveOperation",
        mode: "QTextCursor.MoveMode" = ...,
        n: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#movePosition

        **bool QTextCursor::movePosition(QTextCursor::MoveOperation operation ,
        QTextCursor::MoveMode mode = MoveAnchor, int n = 1)**

        Moves the cursor by performing the given **operation** **n** times,
        using the specified **mode** , and returns `true` if all operations were
        completed successfully; otherwise returns `false`.

        For example, if this function is repeatedly used to seek to the end of
        the next word, it will eventually fail when the end of the document is
        reached.

        By default, the move operation is performed once ( **n** = 1).

        If **mode** is `KeepAnchor`, the cursor selects the text it moves over.
        This is the same effect that the user achieves when they hold down the
        Shift key and move the cursor with the cursor keys.

        **See also** **setVisualNavigation** ().
        """
        ...

    @typing.overload
    def insertText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertText

        **void QTextCursor::insertText(const QString & text )**

        Inserts **text** at the current position, using the current character
        format.

        If there is a selection, the selection is deleted and replaced by
        **text** , for example:

        cursor.clearSelection();
            cursor.movePosition(**QTextCursor**
        ::NextWord, **QTextCursor** ::KeepAnchor);
            cursor.insertText("Hello
        World");

        This clears any existing selection, selects the word at the cursor (i.e.
        from **position** () forward), and replaces the selection with the
        phrase "Hello World".

        Any ASCII linefeed characters (\\n) in the inserted text are transformed
        into unicode block separators, corresponding to **insertBlock** ()
        calls.

        **See also** **charFormat** () and **hasSelection** ().
        """
        ...

    @typing.overload
    def insertText(self, text: str, format: "QTextCharFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#insertText-1

        **void QTextCursor::insertText(const QString & text , const
        QTextCharFormat & format )**

        This is an overloaded function.

        Inserts **text** at the current position with the given **format**.
        """
        ...

    def anchor(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#anchor

        **int QTextCursor::anchor() const**

        Returns the anchor position; this is the same as **position** () unless
        there is a selection in which case **position** () marks one end of the
        selection and anchor() marks the other end. Just like the cursor
        position, the anchor position is between characters.

        **See also** **position** (), **setPosition** (), **movePosition** (),
        **selectionStart** (), and **selectionEnd** ().
        """
        ...

    def position(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#position

        **int QTextCursor::position() const**

        Returns the absolute position of the cursor within the document. The
        cursor is positioned between characters.

        **Note:** The "characters" in this case refer to the string of **QChar**
        objects, i.e. 16-bit Unicode characters, and the position is considered
        an index into this string. This does not necessarily correspond to
        individual graphemes in the writing system, as a single grapheme may be
        represented by multiple Unicode characters, such as in the case of
        surrogate pairs, linguistic ligatures or diacritics.

        **See also** **setPosition** (), **movePosition** (), **anchor** (), and
        **positionInBlock** ().
        """
        ...

    def setPosition(self, pos: int, mode: "QTextCursor.MoveMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#setPosition

        **void QTextCursor::setPosition(int pos , QTextCursor::MoveMode m =
        MoveAnchor)**

        Moves the cursor to the absolute position in the document specified by
        **pos** using a `MoveMode` specified by **m**. The cursor is positioned
        between characters.

        **Note:** The "characters" in this case refer to the string of **QChar**
        objects, i.e. 16-bit Unicode characters, and **pos** is considered an
        index into this string. This does not necessarily correspond to
        individual graphemes in the writing system, as a single grapheme may be
        represented by multiple Unicode characters, such as in the case of
        surrogate pairs, linguistic ligatures or diacritics. For a more generic
        approach to navigating the document, use **movePosition** (), which will
        respect the actual grapheme boundaries in the text.

        **See also** **position** (), **movePosition** (), and **anchor** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcursor.html#isNull

        **bool QTextCursor::isNull() const**

        Returns `true` if the cursor is null; otherwise returns `false`. A null
        cursor is created by the default constructor.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QScrollBar(QAbstractSlider):
    """
    https://doc.qt.io/qt-6/qscrollbar.html

    **Detailed Description**

    A scroll bar is a control that enables the user to access parts of a
    document that is larger than the widget used to display it. It provides a
    visual indication of the user's current position within the document and the
    amount of the document that is visible. Scroll bars are usually equipped
    with other controls that enable more accurate navigation. Qt displays scroll
    bars in a way that is appropriate for each platform.

    If you need to provide a scrolling view onto another widget, it may be more
    convenient to use the **QScrollArea**  class because this provides a
    viewport widget and scroll bars. QScrollBar is useful if you need to
    implement similar functionality for specialized widgets using
    **QAbstractScrollArea** ; for example, if you decide to subclass
    **QAbstractItemView** . For most other situations where a slider control is
    used to obtain a value within a given range, the **QSlider**  class may be
    more appropriate for your needs.

    ![](images/qscrollbar-picture.png)

    Scroll bars typically include four
    separate controls: a slider, scroll arrows, and a page control.

      * a. The
    slider provides a way to quickly go to any part of the document, but does
    not support accurate navigation within large documents.
      * b. The scroll
    arrows are push buttons which can be used to accurately navigate to a
    particular place in a document. For a vertical scroll bar connected to a
    text editor, these typically move the current position one "line" up or
    down, and adjust the position of the slider by a small amount. In editors
    and list boxes a "line" might mean one line of text; in an image viewer it
    might mean 20 pixels.
      * c. The page control is the area over which the
    slider is dragged (the scroll bar's background). Clicking here moves the
    scroll bar towards the click by one "page". This value is usually the same
    as the length of the slider.

    Each scroll bar has a value that indicates how far the slider is from the
    start of the scroll bar; this is obtained with **value** () and set with
    **setValue** (). This value always lies within the range of values defined
    for the scroll bar, from **minimum** () to **maximum** () inclusive. The
    range of acceptable values can be set with **setMinimum** () and
    **setMaximum** (). At the minimum value, the top edge of the slider (for a
    vertical scroll bar) or left edge (for a horizontal scroll bar) will be at
    the top (or left) end of the scroll bar. At the maximum value, the bottom
    (or right) edge of the slider will be at the bottom (or right) end of the
    scroll bar.

    The length of the slider is usually related to the value of the page step,
    and typically represents the proportion of the document area shown in a
    scrolling view. The page step is the amount that the value changes by when
    the user presses the **Page Up** and **Page Down** keys, and is set with
    **setPageStep** (). Smaller changes to the value defined by the line step
    are made using the cursor keys, and this quantity is set with
    **setSingleStep** ().

    Note that the range of values used is independent of the actual size of the
    scroll bar widget. You do not need to take this into account when you choose
    values for the range and the page step.

    The range of values specified for the scroll bar are often determined
    differently to those for a **QSlider**  because the length of the slider
    needs to be taken into account. If we have a document with 100 lines, and we
    can only show 20 lines in a widget, we may wish to construct a scroll bar
    with a page step of 20, a minimum value of 0, and a maximum value of 80.
    This would give us a scroll bar with five "pages".

    ![](images/qscrollbar-values.png)The relationship between a document length,
    the range of values used in a scroll bar, and the page step is simple in
    many common situations. The scroll bar's range of values is determined by
    subtracting a chosen page step from some value representing the length of
    the document. In such cases, the following equation is useful: **document
    length** = **maximum** () - **minimum** () + **pageStep** ().

    QScrollBar only provides integer ranges. Note that although QScrollBar
    handles very large numbers, scroll bars on current screens cannot usefully
    represent ranges above about 100,000 pixels. Beyond that, it becomes
    difficult for the user to control the slider using either the keyboard or
    the mouse, and the scroll arrows will have limited use.

    ScrollBar inherits a comprehensive set of signals from **QAbstractSlider** :

    * **valueChanged** () is emitted when the scroll bar's value has changed.
    The tracking() determines whether this signal is emitted during user
    interaction.
      * **rangeChanged** () is emitted when the scroll bar's range
    of values has changed.
      * **sliderPressed** () is emitted when the user
    starts to drag the slider.
      * **sliderMoved** () is emitted when the user
    drags the slider.
      * **sliderReleased** () is emitted when the user
    releases the slider.
      * **actionTriggered** () is emitted when the scroll
    bar is changed by user interaction or via the **triggerAction** () function.

    A scroll bar can be controlled by the keyboard, but it has a default
    **focusPolicy** () of **Qt::NoFocus** . Use **setFocusPolicy** () to enable
    keyboard interaction with the scroll bar:

    * Left/Right move a horizontal scroll bar by one single step.
      * Up/Down
    move a vertical scroll bar by one single step.
      * PageUp moves up one page.
    * PageDown moves down one page.
      * Home moves to the start (minimum).
      *
    End moves to the end (maximum).

    The slider itself can be controlled by using the **triggerAction** ()
    function to simulate user interaction with the scroll bar controls. This is
    useful if you have many different widgets that use a common range of values.

    Most GUI styles use the **pageStep** () value to calculate the size of the
    slider.

    **See also** **QScrollArea** , **QSlider** , **QDial** , **QSpinBox** ,
    **GUI Design Handbook: Scroll Bar** , and **Sliders Example** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#QScrollBar

        **QScrollBar::QScrollBar(QWidget * parent = nullptr)**

        Constructs a vertical scroll bar.

        The **parent** argument is sent to the **QWidget**  constructor.

        The **minimum**  defaults to 0, the **maximum**  to 99, with a
        **singleStep**  size of 1 and a **pageStep**  size of 10, and an initial
        **value**  of 0.
        """
        ...

    @typing.overload
    def __init__(
        self, orientation: QtCore.Qt.Orientation, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#QScrollBar-1

        **QScrollBar::QScrollBar(Qt::Orientation orientation , QWidget * parent
        = nullptr)**

        Constructs a scroll bar with the given **orientation**.

        The **parent** argument is passed to the **QWidget**  constructor.

        The **minimum**  defaults to 0, the **maximum**  to 99, with a
        **singleStep**  size of 1 and a **pageStep**  size of 10, and an initial
        **value**  of 0.
        """
        ...

    def sliderChange(self, change: QAbstractSlider.SliderChange) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#sliderChange

        **[override virtual protected] void
        QScrollBar::sliderChange(QAbstractSlider::SliderChange change )**

        Reimplements: **QAbstractSlider::sliderChange**
        (QAbstractSlider::SliderChange change).
        """
        ...

    def wheelEvent(self, a0: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#wheelEvent

        **[override virtual protected] void QScrollBar::wheelEvent(QWheelEvent *
        event )**

        Reimplements: **QAbstractSlider::wheelEvent** (QWheelEvent *e).
        """
        ...

    def contextMenuEvent(self, a0: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#contextMenuEvent

        **[override virtual protected] void
        QScrollBar::contextMenuEvent(QContextMenuEvent * event )**

        Reimplements: **QWidget::contextMenuEvent** (QContextMenuEvent *event).
        """
        ...

    def hideEvent(self, a0: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#hideEvent

        **[override virtual protected] void QScrollBar::hideEvent(QHideEvent
        *)**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#mouseMoveEvent

        **[override virtual protected] void
        QScrollBar::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#mouseReleaseEvent

        **[override virtual protected] void
        QScrollBar::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#mousePressEvent

        **[override virtual protected] void
        QScrollBar::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#paintEvent

        **[override virtual protected] void QScrollBar::paintEvent(QPaintEvent
        *)**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionSlider") -> None:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#initStyleOption

        **[virtual protected] void
        QScrollBar::initStyleOption(QStyleOptionSlider * option ) const**

        Initialize **option** with the values from this **QScrollBar** . This
        method is useful for subclasses when they need a **QStyleOptionSlider**
        , but don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#event

        **[override virtual] bool QScrollBar::event(QEvent * event )**

        Reimplements: **QAbstractSlider::event** (QEvent *e).
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qscrollbar.html#sizeHint

        **[override virtual] QSize QScrollBar::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QOpenGLContext(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopenglcontext.html

    **Detailed Description**

    QOpenGLContext represents the OpenGL state of an underlying OpenGL context.
    To set up a context, set its screen and format such that they match those of
    the surface or surfaces with which the context is meant to be used, if
    necessary make it share resources with other contexts with
    **setShareContext** (), and finally call **create** (). Use the return value
    or **isValid** () to check if the context was successfully initialized.

    A context can be made current against a given surface by calling
    **makeCurrent** (). When OpenGL rendering is done, call **swapBuffers** ()
    to swap the front and back buffers of the surface, so that the newly
    rendered content becomes visible. To be able to support certain platforms,
    QOpenGLContext requires that you call **makeCurrent** () again before
    starting rendering a new frame, after calling **swapBuffers** ().

    If the context is temporarily not needed, such as when the application is
    not rendering, it can be useful to delete it in order to free resources. You
    can connect to the **aboutToBeDestroyed** () signal to clean up any
    resources that have been allocated with different ownership from the
    QOpenGLContext itself.

    Once a QOpenGLContext has been made current, you can render to it in a
    platform independent way by using Qt's OpenGL enablers such as
    **QOpenGLFunctions** , **QOpenGLBuffer** , **QOpenGLShaderProgram** , and
    **QOpenGLFramebufferObject** . It is also possible to use the platform's
    OpenGL API directly, without using the Qt enablers, although potentially at
    the cost of portability. The latter is necessary when wanting to use OpenGL
    1.x or OpenGL ES 1.x.

    For more information about the OpenGL API, refer to the official **OpenGL
    documentation** .

    For an example of how to use QOpenGLContext see the **OpenGL Window**
    example.

    **Thread Affinity**

    QOpenGLContext can be moved to a different thread with **moveToThread** ().
    Do not call **makeCurrent** () from a different thread than the one to which
    the QOpenGLContext object belongs. A context can only be current in one
    thread and against one surface at a time, and a thread only has one context
    current at a time.

    **Context Resource Sharing**

    Resources such as textures and vertex buffer objects can be shared between
    contexts. Use **setShareContext** () before calling **create** () to specify
    that the contexts should share these resources. QOpenGLContext internally
    keeps track of a **QOpenGLContextGroup**  object which can be accessed with
    **shareGroup** (), and which can be used to find all the contexts in a given
    share group. A share group consists of all contexts that have been
    successfully initialized and are sharing with an existing context in the
    share group. A non-sharing context has a share group consisting of a single
    context.

    **Default Framebuffer**

    On certain platforms, a framebuffer other than 0 might be the default frame
    buffer depending on the current surface. Instead of calling
    glBindFramebuffer(0), it is recommended that you use
    glBindFramebuffer(ctx->**defaultFramebufferObject** ()), to ensure that your
    application is portable between different platforms. However, if you use
    **QOpenGLFunctions::glBindFramebuffer** (), this is done automatically for
    you.

    **See also** **QOpenGLFunctions** , **QOpenGLBuffer** ,
    **QOpenGLShaderProgram** , and **QOpenGLFramebufferObject** .
    """

    class OpenGLModuleType(enum.Enum):
        LibGL: QOpenGLContext = ...
        LibGLES: QOpenGLContext = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#QOpenGLContext

        **QOpenGLContext::QOpenGLContext(QObject * parent = nullptr)**

        Creates a new OpenGL context instance with parent object **parent**.

        Before it can be used you need to set the proper format and call
        **create** ().

        **See also** **create** () and **makeCurrent** ().
        """
        ...

    @staticmethod
    def globalShareContext() -> "QOpenGLContext":
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#globalShareContext

        **[static, since 5.5] QOpenGLContext
        *QOpenGLContext::globalShareContext()**

        Returns the application-wide shared OpenGL context, if present.
        Otherwise, returns `nullptr`.

        This is useful if you need to upload OpenGL objects (buffers, textures,
        etc.) before creating or showing a **QOpenGLWidget**  or
        **QQuickWidget** .

        **Note:** You must set the **Qt::AA_ShareOpenGLContexts**  flag on
        **QGuiApplication**  before creating the **QGuiApplication**  object,
        otherwise Qt may not create a global shared context.

        **Warning:** Do not attempt to make the context returned by this
        function current on any surface. Instead, you can create a new context
        which shares with the global one, and then make the new context current.

        This function was introduced in Qt 5.5.

        **See also** **Qt::AA_ShareOpenGLContexts** , **setShareContext** (),
        and **makeCurrent** ().
        """
        ...

    @staticmethod
    def supportsThreadedOpenGL() -> bool:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#supportsThreadedOpenGL

        **[static, since 5.5] bool QOpenGLContext::supportsThreadedOpenGL()**

        Returns `true` if the platform supports OpenGL rendering outside the
        main (gui) thread.

        The value is controlled by the platform plugin in use and may also
        depend on the graphics drivers.

        This function was introduced in Qt 5.5.
        """
        ...

    def isOpenGLES(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#isOpenGLES

        **[since 5.3] bool QOpenGLContext::isOpenGLES() const**

        Returns true if the context is an OpenGL ES context.

        If the context has not yet been created, the result is based on the
        requested format set via **setFormat** ().

        This function was introduced in Qt 5.3.

        **See also** **create** (), **format** (), and **setFormat** ().
        """
        ...

    @staticmethod
    def openGLModuleType() -> "QOpenGLContext.OpenGLModuleType":
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#openGLModuleType

        **[static, since 5.3] QOpenGLContext::OpenGLModuleType
        QOpenGLContext::openGLModuleType()**

        Returns the underlying OpenGL implementation type.

        On platforms where the OpenGL implementation is not dynamically loaded,
        the return value is determined during compile time and never changes.

        **Note:** A desktop OpenGL implementation may be capable of creating ES-
        compatible contexts too. Therefore in most cases it is more appropriate
        to check **QSurfaceFormat::renderableType** () or use the convenience
        function **isOpenGLES** ().

        **Note:** This function requires that the **QGuiApplication**  instance
        is already created.

        This function was introduced in Qt 5.3.
        """
        ...

    def hasExtension(self, extension: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#hasExtension

        **bool QOpenGLContext::hasExtension(const QByteArray & extension )
        const**

        Returns `true` if this OpenGL context supports the specified OpenGL
        **extension** , `false` otherwise.

        The context or a sharing context must be current.

        **See also** **extensions** ().
        """
        ...

    def extensions(self) -> typing.Set[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#extensions

        **QSet<QByteArray> QOpenGLContext::extensions() const**

        Returns the set of OpenGL extensions supported by this context.

        The context or a sharing context must be current.

        **See also** **hasExtension** ().
        """
        ...

    @staticmethod
    def areSharing(first: "QOpenGLContext", second: "QOpenGLContext") -> bool:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#areSharing

        **[static] bool QOpenGLContext::areSharing(QOpenGLContext * first ,
        QOpenGLContext * second )**

        Returns `true` if the **first** and **second** contexts are sharing
        OpenGL resources.
        """
        ...

    @staticmethod
    def currentContext() -> "QOpenGLContext":
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#currentContext

        **[static] QOpenGLContext *QOpenGLContext::currentContext()**

        Returns the last context which called **makeCurrent**  in the current
        thread, or `nullptr`, if no context is current.
        """
        ...

    def surface(self) -> QSurface:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#surface

        **QSurface *QOpenGLContext::surface() const**

        Returns the surface the context has been made current with.

        This is the surface passed as an argument to **makeCurrent** ().
        """
        ...

    def getProcAddress(self, procName: QtCore.QByteArray) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#getProcAddress

        **QFunctionPointer QOpenGLContext::getProcAddress(const QByteArray &
        procName ) const**

        Resolves the function pointer to an OpenGL extension function,
        identified by **procName**

        Returns `nullptr` if no such function can be found.
        """
        ...

    def swapBuffers(self, surface: QSurface) -> None:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#swapBuffers

        **void QOpenGLContext::swapBuffers(QSurface * surface )**

        Swap the back and front buffers of **surface**.

        Call this to finish a frame of OpenGL rendering, and make sure to call
        **makeCurrent** () again before issuing any further OpenGL commands, for
        example as part of a new frame.
        """
        ...

    def doneCurrent(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#doneCurrent

        **void QOpenGLContext::doneCurrent()**

        Convenience function for calling **makeCurrent**  with a 0 surface.

        This results in no context being current in the current thread.

        **See also** **makeCurrent** () and **currentContext** ().
        """
        ...

    def makeCurrent(self, surface: QSurface) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#makeCurrent

        **bool QOpenGLContext::makeCurrent(QSurface * surface )**

        Makes the context current in the current thread, against the given
        **surface**. Returns `true` if successful; otherwise returns `false`.
        The latter may happen if the surface is not exposed, or the graphics
        hardware is not available due to e.g. the application being suspended.

        If **surface** is `nullptr` this is equivalent to calling
        **doneCurrent** ().

        Avoid calling this function from a different thread than the one the
        **QOpenGLContext**  instance lives in. If you wish to use
        **QOpenGLContext**  from a different thread you should first make sure
        it's not current in the current thread, by calling **doneCurrent** () if
        necessary. Then call moveToThread(otherThread) before using it in the
        other thread.

        By default Qt employs a check that enforces the above condition on the
        thread affinity. It is still possible to disable this check by setting
        the `Qt::AA_DontCheckOpenGLContextThreadAffinity` application attribute.
        Be sure to understand the consequences of using QObjects from outside
        the thread they live in, as explained in the **QObject thread affinity**
        documentation.

        **See also** **functions** (), **doneCurrent** (), and
        **Qt::AA_DontCheckOpenGLContextThreadAffinity** .
        """
        ...

    def defaultFramebufferObject(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#defaultFramebufferObject

        **GLuint QOpenGLContext::defaultFramebufferObject() const**

        Call this to get the default framebuffer object for the current surface.

        On some platforms (for instance, iOS) the default framebuffer object
        depends on the surface being rendered to, and might be different from 0.
        Thus, instead of calling glBindFramebuffer(0), you should call
        glBindFramebuffer(ctx->defaultFramebufferObject()) if you want your
        application to work across different Qt platforms.

        If you use the glBindFramebuffer() in **QOpenGLFunctions**  you do not
        have to worry about this, as it automatically binds the current
        context's defaultFramebufferObject() when 0 is passed.

        **Note:** Widgets that render via framebuffer objects, like
        **QOpenGLWidget**  and **QQuickWidget** , will override the value
        returned from this function when painting is active, because at that
        time the correct "default" framebuffer is the widget's associated
        backing framebuffer, not the platform-specific one belonging to the top-
        level window's surface. This ensures the expected behavior for this
        function and other classes relying on it (for example,
        **QOpenGLFramebufferObject::bindDefault** () or
        **QOpenGLFramebufferObject::release** ()).

        **See also** **QOpenGLFramebufferObject** .
        """
        ...

    def screen(self) -> "QScreen":
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#screen

        **QScreen *QOpenGLContext::screen() const**

        Returns the screen the context was created for.

        **See also** **setScreen** ().
        """
        ...

    def shareGroup(self) -> QOpenGLContextGroup:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#shareGroup

        **QOpenGLContextGroup *QOpenGLContext::shareGroup() const**

        Returns the share group this context belongs to.
        """
        ...

    def shareContext(self) -> "QOpenGLContext":
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#shareContext

        **QOpenGLContext *QOpenGLContext::shareContext() const**

        Returns the share context this context was created with.

        If the underlying platform was not able to support the requested
        sharing, this will return 0.

        **See also** **setShareContext** ().
        """
        ...

    def format(self) -> "QSurfaceFormat":
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#format

        **QSurfaceFormat QOpenGLContext::format() const**

        Returns the format of the underlying platform context, if **create** ()
        has been called.

        Otherwise, returns the requested format.

        The requested and the actual format may differ. Requesting a given
        OpenGL version does not mean the resulting context will target exactly
        the requested version. It is only guaranteed that the
        version/profile/options combination for the created context is
        compatible with the request, as long as the driver is able to provide
        such a context.

        For example, requesting an OpenGL version 3.x core profile context may
        result in an OpenGL 4.x core profile context. Similarly, a request for
        OpenGL 2.1 may result in an OpenGL 3.0 context with deprecated functions
        enabled. Finally, depending on the driver, unsupported versions may
        result in either a context creation failure or in a context for the
        highest supported version.

        Similar differences are possible in the buffer sizes, for example, the
        resulting context may have a larger depth buffer than requested. This is
        perfectly normal.

        **See also** **setFormat** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#isValid

        **bool QOpenGLContext::isValid() const**

        Returns if this context is valid, i.e. has been successfully created.

        On some platforms the return value of `false` for a context that was
        successfully created previously indicates that the OpenGL context was
        lost.

        The typical way to handle context loss scenarios in applications is to
        check via this function whenever **makeCurrent** () fails and returns
        `false`. If this function then returns `false`, recreate the underlying
        native OpenGL context by calling **create** (), call **makeCurrent** ()
        again and then reinitialize all OpenGL resources.

        On some platforms context loss situations is not something that can
        avoided. On others however, they may need to be opted-in to. This can be
        done by enabling **ResetNotification**  in the **QSurfaceFormat** . This
        will lead to setting `RESET_NOTIFICATION_STRATEGY_EXT` to
        `LOSE_CONTEXT_ON_RESET_EXT` in the underlying native OpenGL context.
        **QOpenGLContext**  will then monitor the status via
        `glGetGraphicsResetStatusEXT()` in every **makeCurrent** ().

        **See also** **create** ().
        """
        ...

    def create(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#create

        **bool QOpenGLContext::create()**

        Attempts to create the OpenGL context with the current configuration.

        The current configuration includes the format, the share context, and
        the screen.

        If the OpenGL implementation on your system does not support the
        requested version of OpenGL context, then **QOpenGLContext**  will try
        to create the closest matching version. The actual created context
        properties can be queried using the **QSurfaceFormat**  returned by the
        **format** () function. For example, if you request a context that
        supports OpenGL 4.3 Core profile but the driver and/or hardware only
        supports version 3.2 Core profile contexts then you will get a 3.2 Core
        profile context.

        Returns `true` if the native context was successfully created and is
        ready to be used with **makeCurrent** (), **swapBuffers** (), etc.

        **Note:** If the context already exists, this function destroys the
        existing context first, and then creates a new one.

        **See also** **makeCurrent** () and **format** ().
        """
        ...

    def setScreen(self, screen: "QScreen") -> None:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#setScreen

        **void QOpenGLContext::setScreen(QScreen * screen )**

        Sets the **screen** the OpenGL context should be valid for. You need to
        call **create** () before it takes effect.

        **See also** **screen** ().
        """
        ...

    def setShareContext(self, shareContext: "QOpenGLContext") -> None:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#setShareContext

        **void QOpenGLContext::setShareContext(QOpenGLContext * shareContext )**

        Makes this context share textures, shaders, and other OpenGL resources
        with **shareContext**. You need to call **create** () before it takes
        effect.

        **See also** **shareContext** ().
        """
        ...

    def setFormat(self, format: "QSurfaceFormat") -> None:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#setFormat

        **void QOpenGLContext::setFormat(const QSurfaceFormat & format )**

        Sets the **format** the OpenGL context should be compatible with. You
        need to call **create** () before it takes effect.

        When the format is not explicitly set via this function, the format
        returned by **QSurfaceFormat::defaultFormat** () will be used. This
        means that when having multiple contexts, individual calls to this
        function can be replaced by one single call to
        **QSurfaceFormat::setDefaultFormat** () before creating the first
        context.

        **See also** **format** ().
        """
        ...

    @property
    def aboutToBeDestroyed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qopenglcontext.html#aboutToBeDestroyed

        **[signal] void QOpenGLContext::aboutToBeDestroyed()**

        This signal is emitted before the underlying native OpenGL context is
        destroyed, such that users may clean up OpenGL resources that might
        otherwise be left dangling in the case of shared OpenGL contexts.

        If you wish to make the context current in order to do clean-up, make
        sure to only connect to the signal using a direct connection.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomDocumentType(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomdocumenttype.html

    **Detailed Description**

    The QDomDocumentType class allows read-only access to some of the data
    structures in the DTD: it can return a map of all **entities** () and
    **notations** (). In addition the function **name** () returns the name of
    the document type as specified in the &lt;!DOCTYPE name&gt; tag. This class
    also provides the **publicId** (), **systemId** () and **internalSubset** ()
    functions.

    **See also** **QDomDocument** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#QDomDocumentType

        **QDomDocumentType::QDomDocumentType()**

        Creates an empty QDomDocumentType object.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomDocumentType") -> None:
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#QDomDocumentType-1

        **QDomDocumentType::QDomDocumentType(const QDomDocumentType & n )**

        Constructs a copy of **n**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#nodeType

        **QDomNode::NodeType QDomDocumentType::nodeType() const**

        Returns `DocumentTypeNode`.

        **See also** **isDocumentType** () and **QDomNode::toDocumentType** ().
        """
        ...

    def internalSubset(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#internalSubset

        **QString QDomDocumentType::internalSubset() const**

        Returns the internal subset of the document type or an empty string if
        there is no internal subset.

        **See also** **publicId** () and **systemId** ().
        """
        ...

    def systemId(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#systemId

        **QString QDomDocumentType::systemId() const**

        Returns the system identifier of the external DTD subset or an empty
        string if there is no system identifier.

        **See also** **publicId** (), **internalSubset** (), and
        **QDomImplementation::createDocumentType** ().
        """
        ...

    def publicId(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#publicId

        **QString QDomDocumentType::publicId() const**

        Returns the public identifier of the external DTD subset or an empty
        string if there is no public identifier.

        **See also** **systemId** (), **internalSubset** (), and
        **QDomImplementation::createDocumentType** ().
        """
        ...

    def notations(self) -> "QDomNamedNodeMap":
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#notations

        **QDomNamedNodeMap QDomDocumentType::notations() const**

        Returns a map of all notations described in the DTD.
        """
        ...

    def entities(self) -> "QDomNamedNodeMap":
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#entities

        **QDomNamedNodeMap QDomDocumentType::entities() const**

        Returns a map of all entities described in the DTD.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomdocumenttype.html#name

        **QString QDomDocumentType::name() const**

        Returns the name of the document type as specified in the &lt;!DOCTYPE
        name&gt; tag.

        **See also** **nodeName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QCameraDevice(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcameradevice.html

    **Detailed Description**

    QCameraDevice represents a physical camera device and its properties.

    You can discover what cameras are available on a system using the
    availableCameras() and defaultCamera() functions. These are contained within
    QtMultimedia::MediaDevices.

    This example prints the name of all available cameras:

    const **QList** <**QCameraDevice** > cameras = **QMediaDevices**
    ::videoInputs();
        for (const **QCameraDevice**  &cameraDevice : cameras)
    **qDebug** () << cameraDevice.description();

    A QCameraDevice can be used to construct a **QCamera** . The following
    example instantiates a **QCamera**  whose camera device is named `mycamera`:

    const **QList** <**QCameraDevice** > cameras = **QMediaDevices**
    ::videoInputs();
        for (const **QCameraDevice**  &cameraDevice : cameras)
    {
            if (cameraDevice.description() == "mycamera")
                camera =
    new **QCamera** (cameraDevice);
        }

    You can also use QCameraDevice to get general information about a camera
    device such as description, physical position on the system, or camera
    sensor orientation.

    **QCamera**  myCamera;
        **QCameraDevice**  cameraDevice =
    camera->cameraDevice();

        if (cameraDevice.position() ==
    **QCameraDevice** ::FrontFace)
            **qDebug** () << "The camera is on
    the front face of the hardware system.";
        else if
    (cameraDevice.position() == **QCameraDevice** ::BackFace)
            **qDebug**
    () << "The camera is on the back face of the hardware system.";
    **qDebug** () << "The camera sensor orientation is " <<
    cameraDevice.orientation() << " degrees.";

    **See also** **QCamera** .
    """

    class Position(enum.Enum):
        UnspecifiedPosition: QCameraDevice = ...
        BackFace: QCameraDevice = ...
        FrontFace: QCameraDevice = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#QCameraDevice

        **QCameraDevice::QCameraDevice()**

        Constructs a null camera device
        """
        ...

    @typing.overload
    def __init__(self, other: "QCameraDevice") -> None:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#QCameraDevice-1

        **QCameraDevice::QCameraDevice(const QCameraDevice & other )**

        Constructs a copy of **other**.
        """
        ...

    def videoFormats(self) -> typing.List[QCameraFormat]:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#videoFormats

        **QList<QCameraFormat> QCameraDevice::videoFormats() const**

        Returns the video formats supported by the camera.

        **Note:** Getter function for property videoFormats.
        """
        ...

    def photoResolutions(self) -> typing.List[QtCore.QSize]:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#photoResolutions

        **QList<QSize> QCameraDevice::photoResolutions() const**

        Returns a list of resolutions that the camera can use to capture still
        images.

        **See also** **QImageCapture** .
        """
        ...

    def position(self) -> "QCameraDevice.Position":
        """
        https://doc.qt.io/qt-6/qcameradevice.html#position

        **QCameraDevice::Position QCameraDevice::position() const**

        Returns the physical position of the camera on the hardware system.

        **Note:** Getter function for property position.
        """
        ...

    def isDefault(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#isDefault

        **bool QCameraDevice::isDefault() const**

        Returns true if this is the default camera device.

        **Note:** Getter function for property isDefault.
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#description

        **QString QCameraDevice::description() const**

        Returns the human-readable description of the camera.

        Use this string to present the device to the user.

        **Note:** Getter function for property description.
        """
        ...

    def id(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#id

        **QByteArray QCameraDevice::id() const**

        Returns the device id of the camera

        This is a unique ID to identify the camera and may not be human-
        readable.

        **Note:** Getter function for property id.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcameradevice.html#isNull

        **bool QCameraDevice::isNull() const**

        Returns true if this **QCameraDevice**  is null or invalid.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QSGClipNode(QSGBasicGeometryNode):
    """
    https://doc.qt.io/qt-6/qsgclipnode.html

    **Detailed Description**

    Clipping applies to the node's subtree and can be nested. Multiple clip
    nodes will be accumulated by intersecting all their geometries. The
    accumulation happens as part of the rendering.

    Clip nodes must have a geometry before they can be added to the scene graph.

    Clipping is usually implemented by using the stencil buffer.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgclipnode.html#QSGClipNode

        **QSGClipNode::QSGClipNode()**

        Creates a new QSGClipNode without a geometry.

        The clip node must have a geometry before it can be added to the scene
        graph.
        """
        ...

    def clipRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgclipnode.html#clipRect

        **QRectF QSGClipNode::clipRect() const**

        Returns the clip rect of this node.

        **See also** **setClipRect** ().
        """
        ...

    def setClipRect(self, a0: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgclipnode.html#setClipRect

        **void QSGClipNode::setClipRect(const QRectF & rect )**

        Sets the clip rect of this clip node to **rect**.

        When a rectangular clip is set in combination with **setIsRectangular**
        the renderer may in some cases use a more optimal clip method.

        **See also** **clipRect** ().
        """
        ...

    def isRectangular(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgclipnode.html#isRectangular

        **bool QSGClipNode::isRectangular() const**

        Returns if this clip node has a rectangular clip.

        **See also** **setIsRectangular** ().
        """
        ...

    def setIsRectangular(self, rectHint: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsgclipnode.html#setIsRectangular

        **void QSGClipNode::setIsRectangular(bool rectHint )**

        Sets whether this clip node has a rectangular clip to **rectHint**.

        This is an optimization hint which means that the renderer can use
        scissoring instead of stencil, which is significantly faster.

        When this hint is set and it is applicable, the clip region will be
        generated from **clipRect** () rather than **geometry** ().

        By default this property is `false`.

        **See also** **isRectangular** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickAsyncImageProvider(QQuickImageProvider):
    """
    https://doc.qt.io/qt-6/qquickasyncimageprovider.html

    **Detailed Description**

    See the **Image Response Provider Example**  for a complete implementation.

    **See also** **QQuickImageProvider** .
    """

    def __init__(self) -> None:
        ...

    def requestImageResponse(
        self, id: str, requestedSize: QtCore.QSize
    ) -> QQuickImageResponse:
        """
        https://doc.qt.io/qt-6/qquickasyncimageprovider.html#requestImageRespons
        e

        **[pure virtual] QQuickImageResponse
        *QQuickAsyncImageProvider::requestImageResponse(const QString & id ,
        const QSize & requestedSize )**

        Implement this method to return the job that will provide the texture
        with **id**.

        The **id** is the requested image source, with the "image:" scheme and
        provider identifier removed. For example, if the image **source**  was
        "image://myprovider/icons/home", the given **id** would be "icons/home".

        The **requestedSize** corresponds to the **Image::sourceSize**
        requested by an Image item. If **requestedSize** is a valid size, the
        image returned should be of that size.

        **Note:** this method may be called by multiple threads, so ensure the
        implementation of this method is reentrant.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6.QtOpenGL import *


class QOpenGLVersionFunctionsFactory(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopenglversionfunctionsfactory.html

    **Detailed Description**
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QOpenGLVersionFunctionsFactory") -> None:
        ...

    @staticmethod
    def get(
        versionProfile: "QOpenGLVersionProfile" = ...,
        context: typing.Optional[QtGui.QOpenGLContext] = ...,
    ) -> QAbstractOpenGLFunctions:
        """
        https://doc.qt.io/qt-6/qopenglversionfunctionsfactory.html#get

        **[static] QAbstractOpenGLFunctions
        *QOpenGLVersionFunctionsFactory::get(const QOpenGLVersionProfile &
        versionProfile = QOpenGLVersionProfile(), QOpenGLContext * context =
        nullptr)**

        Returns a pointer to an object that provides access to all functions for
        the **versionProfile** of the **context**. There is no need to call
        QAbstractOpenGLFunctions::initializeOpenGLFunctions() as long as the
        **context** is current. It is also possible to call this function when
        the **context** is not current, but in that case it is the caller's
        responsibility to ensure proper initialization by calling
        QAbstractOpenGLFunctions::initializeOpenGLFunctions() afterwards.

        Usually one would use the template version of this function to
        automatically have the result cast to the correct type.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6.QtDesigner import *
import enum


class QDesignerFormWindowCursorInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html

    **Detailed Description**

    QDesignerFormWindowCursorInterface is a convenience class that provides an
    interface to the associated form window's text cursor; it provides a
    collection of functions that enables you to query a given form window's
    selection and change the selection's focus according to defined modes
    (**MoveMode** ) and movements (**MoveOperation** ). You can also use the
    interface to query the form's widgets and change their properties.

    The interface is not intended to be instantiated directly, but to provide
    access to the selections and widgets of **Qt Designer** 's current form
    windows. **QDesignerFormWindowInterface**  always provides an associated
    cursor interface. The form window for a given widget can be retrieved using
    the static **QDesignerFormWindowInterface::findFormWindow** () functions.
    For example:

    **QDesignerFormWindowInterface**  *formWindow = 0;
            formWindow =
    **QDesignerFormWindowInterface** ::findFormWindow(myWidget);
    formWindow->cursor()->setProperty(myWidget, myProperty, newValue);

    You can retrieve any of **Qt Designer** 's current form windows through **Qt
    Designer** 's **form window manager** .

    Once you have a form window's cursor interface, you can check if the form
    window has a selection at all using the **hasSelection** () function. You
    can query the form window for its total **widgetCount** () and
    **selectedWidgetCount** (). You can retrieve the currently selected widget
    (or widgets) using the **current** () or **selectedWidget** () functions.

    You can retrieve any of the form window's widgets using the **widget** ()
    function, and check if a widget is selected using the **isWidgetSelected**
    () function. You can use the **setProperty** () function to set the selected
    widget's properties, and the **setWidgetProperty** () or
    **resetWidgetProperty** () functions to modify the properties of any given
    widget.

    Finally, you can change the selection by changing the text cursor's
    **position** () using the **setPosition** () and **movePosition** ()
    functions.

    **See also** **QDesignerFormWindowInterface**  and
    **QDesignerFormWindowManagerInterface** .
    """

    class MoveMode(enum.Enum):
        MoveAnchor: QDesignerFormWindowCursorInterface = ...
        KeepAnchor: QDesignerFormWindowCursorInterface = ...

    class MoveOperation(enum.Enum):
        NoMove: QDesignerFormWindowCursorInterface = ...
        Start: QDesignerFormWindowCursorInterface = ...
        End: QDesignerFormWindowCursorInterface = ...
        Next: QDesignerFormWindowCursorInterface = ...
        Prev: QDesignerFormWindowCursorInterface = ...
        Left: QDesignerFormWindowCursorInterface = ...
        Right: QDesignerFormWindowCursorInterface = ...
        Up: QDesignerFormWindowCursorInterface = ...
        Down: QDesignerFormWindowCursorInterface = ...

    def __init__(self) -> None:
        ...

    def isWidgetSelected(self, widget: QtWidgets.QWidget) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#isWidgetS
        elected

        **bool QDesignerFormWindowCursorInterface::isWidgetSelected(QWidget *
        widget ) const**

        Returns true if the specified **widget** is selected; otherwise returns
        false.
        """
        ...

    def resetWidgetProperty(self, widget: QtWidgets.QWidget, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#resetWidg
        etProperty

        **[pure virtual] void
        QDesignerFormWindowCursorInterface::resetWidgetProperty(QWidget * widget
        , const QString & name )**

        Resets the property with the given **name** for the specified **widget**
        to its default value.

        **See also** **setProperty** () and **setWidgetProperty** ().
        """
        ...

    def setWidgetProperty(
        self, widget: QtWidgets.QWidget, name: str, value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#setWidget
        Property

        **[pure virtual] void
        QDesignerFormWindowCursorInterface::setWidgetProperty(QWidget * widget ,
        const QString & name , const QVariant & value )**

        Sets the property with the given **name** for the given **widget** to
        the specified **value**.

        **See also** **resetWidgetProperty** () and **setProperty** ().
        """
        ...

    def setProperty(self, name: str, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#setProper
        ty

        **[pure virtual] void
        QDesignerFormWindowCursorInterface::setProperty(const QString & name ,
        const QVariant & value )**

        Sets the property with the given **name** for the currently selected
        widget to the specified **value**.

        **See also** **setWidgetProperty** () and **resetWidgetProperty** ().
        """
        ...

    def selectedWidget(self, index: int) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#selectedW
        idget

        **[pure virtual] QWidget
        *QDesignerFormWindowCursorInterface::selectedWidget(int index ) const**

        Returns the widget with the given **index** in the list of selected
        widgets.

        **See also** **current** () and **widget** ().
        """
        ...

    def selectedWidgetCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#selectedW
        idgetCount

        **[pure virtual] int
        QDesignerFormWindowCursorInterface::selectedWidgetCount() const**

        Returns the number of selected widgets in the form window.

        **See also** **widgetCount** ().
        """
        ...

    def hasSelection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#hasSelect
        ion

        **[pure virtual] bool QDesignerFormWindowCursorInterface::hasSelection()
        const**

        Returns true if the form window contains a selection; otherwise returns
        false.
        """
        ...

    def widget(self, index: int) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#widget

        **[pure virtual] QWidget *QDesignerFormWindowCursorInterface::widget(int
        index ) const**

        Returns the widget with the given **index** in the list of widgets in
        the form window.

        **See also** **selectedWidget** ().
        """
        ...

    def widgetCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#widgetCou
        nt

        **[pure virtual] int QDesignerFormWindowCursorInterface::widgetCount()
        const**

        Returns the number of widgets in the form window.

        **See also** **selectedWidgetCount** ().
        """
        ...

    def current(self) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#current

        **[pure virtual] QWidget *QDesignerFormWindowCursorInterface::current()
        const**

        Returns the currently selected widget in the form window.

        **See also** **selectedWidget** ().
        """
        ...

    def setPosition(
        self, pos: int, mode: "QDesignerFormWindowCursorInterface.MoveMode" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#setPositi
        on

        **[pure virtual] void
        QDesignerFormWindowCursorInterface::setPosition(int position ,
        QDesignerFormWindowCursorInterface::MoveMode mode = MoveAnchor)**

        Sets the position of the cursor to the given **position** using the
        **mode** to specify how it is moved there.

        **See also** **position** () and **movePosition** ().
        """
        ...

    def position(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#position

        **[pure virtual] int QDesignerFormWindowCursorInterface::position()
        const**

        Returns the cursor position.

        **See also** **setPosition** () and **movePosition** ().
        """
        ...

    def movePosition(
        self,
        op: "QDesignerFormWindowCursorInterface.MoveOperation",
        mode: "QDesignerFormWindowCursorInterface.MoveMode" = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#movePosit
        ion

        **[pure virtual] bool QDesignerFormWindowCursorInterface::movePosition(Q
        DesignerFormWindowCursorInterface::MoveOperation operation ,
        QDesignerFormWindowCursorInterface::MoveMode mode = MoveAnchor)**

        Performs the given **operation** on the cursor using the specified
        **mode** , and returns true if it completed successfully; otherwise
        returns false.

        **See also** **position** () and **setPosition** ().
        """
        ...

    def formWindow(self) -> QDesignerFormWindowInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowcursorinterface.html#formWindo
        w

        **[pure virtual] QDesignerFormWindowInterface
        *QDesignerFormWindowCursorInterface::formWindow() const**

        Returns the form window interface associated with this cursor interface.
        """
        ...
